Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2153)

Unified Diff: build/android/envsetup.sh

Issue 10051021: apk-based test runner work for android (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/buildbot_try_compile_test.sh ('k') | build/android/run_tests.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/envsetup.sh
diff --git a/build/android/envsetup.sh b/build/android/envsetup.sh
index 6c4c563d31e1b15ca7e7b4f0b2c86d8fa1724fcb..1628dbdb7c237230c93e63b679597588d4e619c2 100755
--- a/build/android/envsetup.sh
+++ b/build/android/envsetup.sh
@@ -49,8 +49,13 @@ export ANDROID_TOOLCHAIN="${ANDROID_NDK_ROOT}/toolchains/arm-linux-androideabi-4
export ANDROID_SDK_VERSION="15"
-# Add Android SDK's platform-tools to system path.
-export PATH="${PATH}:${ANDROID_SDK_ROOT}/platform-tools/"
+# Needed by android antfiles when creating apks.
+export ANDROID_SDK_HOME=${ANDROID_SDK_ROOT}
+
+# Add Android SDK/NDK tools to system path.
+export PATH=$PATH:${ANDROID_NDK_ROOT}
+export PATH=$PATH:${ANDROID_SDK_ROOT}/tools
+export PATH=$PATH:${ANDROID_SDK_ROOT}/platform-tools
if [ ! -d "${ANDROID_TOOLCHAIN}" ]; then
echo "Can not find Android toolchain in ${ANDROID_TOOLCHAIN}." >& 2
« no previous file with comments | « build/android/buildbot_try_compile_test.sh ('k') | build/android/run_tests.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698